Cheetah.ErrorCatchers module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.ErrorCatchers module

class `Cheetah.ErrorCatchers.` `BigEcho`(templateObj)

  Bases: `Cheetah.ErrorCatchers.ErrorCatcher`

  `warn`(exc_val, code, rawCode, lineCol)

`Cheetah.ErrorCatchers.` `Echo`

  alias of `ErrorCatcher`

exception `Cheetah.ErrorCatchers.` `Error`

  Bases: `Exception`

class `Cheetah.ErrorCatchers.` `ErrorCatcher`(templateObj)

  Bases: `object`

  `exceptions`()
  `warn`(exc_val, code, rawCode, lineCol)

class `Cheetah.ErrorCatchers.` `KeyError`(templateObj)

  Bases: `Cheetah.ErrorCatchers.ErrorCatcher`

  `warn`(exc_val, code, rawCode, lineCol)

class `Cheetah.ErrorCatchers.` `ListErrors`(templateObj)

  Bases: `Cheetah.ErrorCatchers.ErrorCatcher`

  Accumulate a list of errors.

  `listErrors`()

    Return the list of errors.

  `warn`(exc_val, code, rawCode, lineCol)